# Copyright 2024 The AI Edge Quantizer Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================

"""Default quantization policy."""

from ai_edge_quantizer import qtyping

_TFLOpName = qtyping.TFLOperationName
_OpQuantizationConfig = qtyping.OpQuantizationConfig
_TensorQuantizationConfig = qtyping.TensorQuantizationConfig
_ComputePrecision = qtyping.ComputePrecision
_Granularity = qtyping.QuantGranularity
_INT = qtyping.TensorDataType.INT

DEFAULT_CONFIG_CHECK_POLICY = qtyping.ConfigCheckPolicyDict({
    _TFLOpName.FULLY_CONNECTED: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.BLOCKWISE,
                dtype=_INT,
                block_size=64,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.CONV_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.EMBEDDING_LOOKUP: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
    ],
    _TFLOpName.AVERAGE_POOL_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.RESHAPE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.SOFTMAX: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.DEPTHWISE_CONV_2D: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.TANH: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.TRANSPOSE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.GELU: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.ADD: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.SUB: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.MUL: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.BATCH_MATMUL: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.MEAN: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.RSQRT: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.CONCATENATION: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.STRIDED_SLICE: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.SPLIT: [
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
    _TFLOpName.CONV_2D_TRANSPOSE: [
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=None,
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=4,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.FLOAT,
            explicit_dequantize=True,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=False,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.CHANNELWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
        _OpQuantizationConfig(
            activation_tensor_config=_TensorQuantizationConfig(
                num_bits=16,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            weight_tensor_config=_TensorQuantizationConfig(
                num_bits=8,
                symmetric=True,
                granularity=_Granularity.TENSORWISE,
                dtype=_INT,
            ),
            compute_precision=_ComputePrecision.INTEGER,
        ),
    ],
})

# Add configurations for virtual input/output ops.
valid_io_activation_configs = [
    None,
    _TensorQuantizationConfig(
        num_bits=8,
        symmetric=True,
        granularity=_Granularity.TENSORWISE,
        dtype=_INT,
    ),
    _TensorQuantizationConfig(
        num_bits=8,
        symmetric=False,
        granularity=_Granularity.TENSORWISE,
        dtype=_INT,
    ),
    _TensorQuantizationConfig(
        num_bits=16,
        symmetric=True,
        granularity=_Granularity.TENSORWISE,
        dtype=_INT,
    ),
]
# Virtual input/output ops do not have any weights. All weight configs
# are valid so configs of inputs/outputs can be picked up by ALL_SUPPORTED.
valid_io_weight_configs = []
for num_bits in [4, 8]:
  for symmetric in [True, False]:
    for granularity in [
        _Granularity.TENSORWISE,
        _Granularity.CHANNELWISE,
    ]:
      valid_io_weight_configs.append(
          _TensorQuantizationConfig(
              num_bits=num_bits,
              symmetric=symmetric,
              granularity=granularity,
              dtype=_INT,
          )
      )

valid_io_op_configs = []
for valid_activation_config in valid_io_activation_configs:
  for valid_weight_config in valid_io_weight_configs:
    for compute_precision in [
        _ComputePrecision.INTEGER,
        _ComputePrecision.FLOAT,
    ]:
      # Exclude float compute precision with valid activation config.
      if (
          valid_activation_config is not None
          and compute_precision == _ComputePrecision.FLOAT
      ):
        continue
      for explicit_dequantize in [True, False]:
        valid_io_op_configs.append(
            _OpQuantizationConfig(
                activation_tensor_config=valid_activation_config,
                weight_tensor_config=valid_weight_config,
                compute_precision=compute_precision,
                explicit_dequantize=explicit_dequantize,
            )
        )

DEFAULT_CONFIG_CHECK_POLICY[_TFLOpName.INPUT] = valid_io_op_configs
DEFAULT_CONFIG_CHECK_POLICY[_TFLOpName.OUTPUT] = valid_io_op_configs
